import Vue from "vue";
import Keyboard from "./components/Keyboard.vue";
import store from "./store";

const createKeyboard = (input) => {
  const keyboardDiv = document.createElement("div");
  input.parentElement.appendChild(keyboardDiv);
  new Vue({
    store,
    render: (h) => {
      return h(Keyboard, {
        props: {
          inputField: input,
          manager: true,
        },
      });
    },
    el: keyboardDiv,
  });
};

// Open the keyboard on inputs and text areas
const inputFields = [
  ...document.getElementsByTagName("input"),
  ...document.getElementsByTagName("textarea"),
];

for (const input of inputFields) {
  // Handle the case where the input is already focused when this script is loaded
  if (document.activeElement === input) createKeyboard(input);

  // Open the keyboard once when focusing a new input
  input.onfocus = () => {
    if (input.parentElement.querySelector("#teklia-virtual-keyboard") !== null)
      return;
    createKeyboard(input);
  };

  // The keyboard handle when to be removed by itself
  input.addEventListener("vk_rmkeyboard", (e) => {
    const keyboard = e.detail;
    keyboard.$destroy();
    keyboard.$el.parentElement.removeChild(keyboard.$el);
  });
}
